Author: David Goodger; open to all Docutils developers
Date: 2017-07-05

# Docutils Web Site

Author: | David Goodger; open to all Docutils developers
Contact: | docutils-develop@lists.sourceforge.net
Date: | 2017-07-05
Revision: | 8133
Copyright: | This document has been placed in the public domain.

The Docutils web site, <http://docutils.sourceforge.net/>, is maintained by the `docutils-update.local` script, run by project maintainers on their local machines. The script will process any .txt file which is newer than the corresponding .html file in the local copy of the project's web directory and upload the changes to the web site at SourceForge.

Please do not add any generated .html files to the Docutils repository. They will be generated automatically after a one-time setup (described below).

The docutils-update.local script is located at `sandbox/infrastructure/docutils-update.local`.

If you want to share files via the web, you can upload them using the uploaddocutils.sh script (`sandbox/infrastructure/uploaddocutils.sh`).

# Setting Up

(TBA)

Hint

Anyone with checkin privileges can be a web-site maintainer. You need to set up the directories for a local website build.

The procedure for that was on the docutils-devel list a while ago.

# Adding .txt Files

## User/Contributor

When adding a new .txt file that should be converted to HTML:

1. Edit sandbox/infrastructure/htmlfiles.lst, and add the .html file corresponding to the new .txt file (please keep the sorted order).
2. Commit the edited version to the SVN repository.

## Maintainer

1. If there are new directories in the SVN, allow the update script to run once to create the directories in the filesystem before preparing for HTML processing.

2. Run the sandbox/infrastructure/update-htmlfiles shell script to generate .html files:

       cd <DOCUTILS-ROOT>/docutils/
       sandbox/infrastructure/update-htmlfiles \
       sandbox/infrastructure/htmlfiles.lst

   (Maybe this should become part of docutils-update.local.)

# Removing Files & Directories

1. Remove from SVN
2. Remove to-be-generated HTML files from `sandbox/infrastructure/htmlfiles.lst`.
3. Removing files and directories from SVN will not trigger their removal from the web site. Files and directories must be manually removed from sourceforge.net (under `/home/project-web/docutils/htdocs/`).